.results_on_deck .ui-icon-trash {
	float: left;
	cursor: pointer;
}
.results_on_deck {
	padding: 0.25em 0;
}
form .aligned .results_on_deck {
    padding-left: 38px;
    margin-left: 7em;
}
.results_on_deck > div {
	margin-bottom: 0.5em;
}
.ui-autocomplete-loading {
	background:  url('https://github.com/crucialfelix/django-ajax-selects/raw/master/ajax_select/static/images/loading-indicator.gif') no-repeat;
    background-origin: content-box;
	background-position: right;
}
ul.ui-autocomplete {
/*
this is the dropdown menu.
    max-width: 320px;

if max-width is not set and you are using django-admin
  then the dropdown is the width of your whole page body (totally wrong).
  so set it in your own css to your preferred width of dropdown
  OR the ajax_select.js will automatically match it to the size of the text field
  which is what jquery's autocomplete does normally (but django's admin is breaking).
tldr: it just works. set max-width if you want it wider
*/
	margin: 0;
	padding: 0;
	position: absolute;
}
ul.ui-autocomplete li {
    list-style-type: none;
	padding: 0;
}
ul.ui-autocomplete li a {
	display: block;
	padding: 2px 3px;
	cursor: pointer;
}
